Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(41)

Unified Diff: src/codec/SkRawAdapterCodec.h

Issue 1520403003: Prototype of RAW decoding in Skia. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Fix bug in transferBuffer. Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/codec/SkRawAdapterCodec.h
diff --git a/src/codec/SkWebpAdapterCodec.h b/src/codec/SkRawAdapterCodec.h
similarity index 53%
copy from src/codec/SkWebpAdapterCodec.h
copy to src/codec/SkRawAdapterCodec.h
index ece46a668ad7c0307163258553fe8ca4d2dea571..46600b851e20cd943491d05618829eb38317afd5 100644
--- a/src/codec/SkWebpAdapterCodec.h
+++ b/src/codec/SkRawAdapterCodec.h
@@ -4,28 +4,33 @@
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-#ifndef SkWebpAdapterCodec_DEFINED
-#define SkWebpAdapterCodec_DEFINED
+
+#ifndef SkRawAdapterCodec_DEFINED
+#define SkRawAdapterCodec_DEFINED
#include "SkAndroidCodec.h"
-#include "SkWebpCodec.h"
+#include "SkCodec.h"
+#include "SkEncodedFormat.h"
+#include "SkRawCodec.h"
+#include "SkStream.h"
+#include "SkTypes.h"
/**
* This class implements the functionality of SkAndroidCodec. It uses an
* SkWebpCodec.
*/
-class SkWebpAdapterCodec : public SkAndroidCodec {
+class SkRawAdapterCodec : public SkAndroidCodec {
public:
- explicit SkWebpAdapterCodec(SkWebpCodec*);
+ explicit SkRawAdapterCodec(SkRawCodec*);
- virtual ~SkWebpAdapterCodec() {}
+ virtual ~SkRawAdapterCodec() {}
protected:
SkISize onGetSampledDimensions(int sampleSize) const override;
- bool onGetSupportedSubset(SkIRect* desiredSubset) const override;
+ bool onGetSupportedSubset(SkIRect* desiredSubset) const override { return false; }
msarett 2016/01/20 20:23:17 I believe that this needs to be /*desiredSubset*/
yujieqin 2016/01/20 21:42:19 Done.
SkCodec::Result onGetAndroidPixels(const SkImageInfo& info, void* pixels, size_t rowBytes,
const AndroidOptions& options) override;
@@ -34,4 +39,4 @@ private:
typedef SkAndroidCodec INHERITED;
};
-#endif // SkWebpAdapterCodec_DEFINED
+#endif // SkRawAdapterCodec_DEFINED

Powered by Google App Engine
This is Rietveld 408576698
@@ -4,28 +4,33 @@
/**
- * This class implements the functionality of SkAndroidCodec. It uses an
- * SkWebpCodec.
+ * This class implements the functionality of SkAndroidCodec. It uses an
+ * SkRawCodec.
*/